﻿using Windows.Foundation;
using Windows.Foundation.Metadata;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "FrameworkElement 엘리먼트 : 포커스 사각형 크기/색상 변경하기";

            #endregion

            if
            (
                ApiInformation.IsApiContractPresent("Windows.Foundation.UniversalApiContract", 6) &&
                Application.Current.FocusVisualKind == FocusVisualKind.Reveal
            )
            {
                this.primaryColorPicker.Color   = (Resources["SystemControlRevealFocusVisualBrush"   ] as SolidColorBrush).Color;
                this.secondaryColorPicker.Color = (Resources["SystemControlFocusVisualSecondaryBrush"] as SolidColorBrush).Color;

                this.primaryColorPickerButton.Background   = new SolidColorBrush(this.primaryColorPicker.Color  );
                this.secondaryColorPickerButton.Background = new SolidColorBrush(this.secondaryColorPicker.Color);
            }
            else
            {
                this.primaryColorPickerButton.Background   = new SolidColorBrush(this.primaryColorPicker.Color  );
                this.secondaryColorPickerButton.Background = new SolidColorBrush(this.secondaryColorPicker.Color);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 확인 버튼 클릭시 처리하기 - confirmationButton_Click(sender, e)

        /// <summary>
        /// 확인 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void confirmationButton_Click(object sender, RoutedEventArgs e)
        {
            this.primaryColorPickerButton.Background   = new SolidColorBrush(this.primaryColorPicker.Color  );
            this.secondaryColorPickerButton.Background = new SolidColorBrush(this.secondaryColorPicker.Color);

            this.primaryColorPickerButton.Flyout.Hide();
            this.secondaryColorPickerButton.Flyout.Hide();
        }

        #endregion
        #region 마진 초기화 버튼 클릭시 처리하기 - resetMarginButton_Click(sender, e)

        /// <summary>
        /// 마진 초기화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void resetMarginButton_Click(object sender, RoutedEventArgs e)
        {
            this.marginSlider.Value = -1 * (this.primaryThicknessSlider.Value + this.secondaryThicknessSlider.Value);
        }

        #endregion
        #region 키보드 포커스 이동 버튼 클릭시 처리하기 - moveKeyboardFocusButton_Click(sender, e)

        /// <summary>
        /// 키보드 포커스 이동 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void moveKeyboardFocusButton_Click(object sender, RoutedEventArgs e)
        {
            this.exampleButton.Focus(FocusState.Keyboard);
        }

        #endregion
    }
}